Attribute VB_Name = "MMain"
'********************************************************************************
'* Component:       MMain
'* Author:          Craig Jasper, Jr.
'* Machine:         CRAIG [ID: 4850] | Windows 2000 Server (Service Pack 2)
'* Modified:        7/14/2001
'********************************************************************************

Option Explicit

Private Declare Function FindWindow Lib "user32" Alias "FindWindowA" _
    (ByVal lpClassName As String, _
    ByVal lpWindowName As String) As Long

Private Declare Function FindWindowEx Lib "user32" Alias "FindWindowExA" _
    (ByVal hWnd1 As Long, _
    ByVal hWnd2 As Long, _
    ByVal lpsz1 As String, _
    ByVal lpsz2 As String) As Long
    
Private Declare Function IsWindow Lib "user32" _
    (ByVal hWnd As Long) As Long

Private Declare Function SendMessageByNum Lib "user32" Alias "SendMessageA" _
    (ByVal hWnd As Long, _
    ByVal wMsg As Long, _
    ByVal wParam As Long, _
    ByVal lParam As Long) As Long
    
Private Declare Function SendMessageByString Lib "user32" Alias "SendMessageA" _
    (ByVal hWnd As Long, _
    ByVal wMsg As Long, _
    ByVal wParam As Long, _
    ByVal lParam As String) As Long

Private Declare Function SetWindowPos Lib "user32" _
    (ByVal hWnd As Long, _
    ByVal hWndInsertAfter As Long, _
    ByVal x As Long, _
    ByVal y As Long, _
    ByVal cx As Long, _
    ByVal cy As Long, _
    ByVal wFlags As Long) As Long

Private Const HWND_TOPMOST = -1
Private Const HWND_NOTOPMOST = -2

Private Const SWP_NOMOVE = 2
Private Const SWP_NOSIZE = 1
Private Const FLAGS = SWP_NOMOVE Or SWP_NOSIZE

Private Const WM_GETTEXT = &HD
Private Const WM_GETTEXTLENGTH = &HE
Private Const WM_SETTEXT = &HC

'********************************************************************************
' Routine:        AOLIcon
' Description:    Obtains handle to Send button.
' Returns:        Long value containing handle.
'********************************************************************************
Public Function AOLIcon() As Long
    Dim lngAOLFrame         As Long
    Dim lngMDIClient        As Long
    Dim lngAOLChild         As Long
    Dim intFor              As Integer
    
    lngAOLFrame = FindWindow("AOL Frame25", vbNullString)
    lngMDIClient = FindWindowEx(lngAOLFrame, 0&, "MDIClient", vbNullString)
    lngAOLChild = FindWindowEx(lngMDIClient, 0&, "AOL Child", vbNullString)
    AOLIcon = FindWindowEx(lngAOLChild, 0&, "_AOL_Icon", vbNullString)
    
    For intFor = 1 To 4
        AOLIcon = FindWindowEx(lngAOLChild, AOLIcon, "_AOL_Icon", vbNullString)
    Next
End Function

'********************************************************************************
' Routine:        ClearText
' Description:    Clears the text from the RICHCNTL. The
'                 purpose of this is to clear the text when
'                 the send button is clicked or the Enter
'                 key is presses. Since nodef is set to True
'                 in the Subclassing control's event the text
'                 will not be cleared and the message will be
'                 ignored. So this will clear the text like
'                 it would if nodef was set to False.
'********************************************************************************
Public Sub ClearText()
    On Error GoTo PROC_ERR
    
    If IsWindow(RICHCNTL) Then
        Call SendMessageByString(RICHCNTL, WM_SETTEXT, 0&, "")
    Else
        MsgBox "Cannot find the RICHCNTL.", vbCritical
    End If
    
    Exit Sub
PROC_ERR:
    MsgBox "Error: " & Err.Description & vbCrLf & "Routine: ClearText", vbCritical
End Sub

'********************************************************************************
' Routine:        GetText
' Description:    Obtains text from handle.
' Parameters:     hWnd (Long): Handle to get text from.
' Returns:        String containing text from handle specified.
'********************************************************************************
Public Function GetText(hWnd As Long) As String
    On Error GoTo PROC_ERR
    
    Dim lngLen        As Long
    Dim strTmp        As String
    
    If IsWindow(hWnd) Then
        lngLen = SendMessageByNum(hWnd, WM_GETTEXTLENGTH, 0&, 0&)
        strTmp = String$(lngLen + 1, Chr$(0))
        Call SendMessageByString(hWnd, WM_GETTEXT, lngLen, strTmp)
    
        GetText = Left$(strTmp, InStr(strTmp, Chr$(0)) - 1)
    Else
        MsgBox "Invalid window.", vbCritical
    End If
    
    Exit Function
PROC_ERR:
    MsgBox "Error: " & Err.Description & vbCrLf & "Routine: GetText", vbCritical
End Function

'********************************************************************************
' Routine:        RICHCNTL
' Description:    Obtains handle to AOL's RICHCNTL.
' Returns:        Long value containing handle.
'********************************************************************************
Public Function RICHCNTL() As Long
    Dim lngAOLFrame         As Long
    Dim lngMDIClient        As Long
    Dim lngAOLChild         As Long
    
    lngAOLFrame = FindWindow("AOL Frame25", vbNullString)
    lngMDIClient = FindWindowEx(lngAOLFrame, 0&, "MDIClient", vbNullString)
    lngAOLChild = FindWindowEx(lngMDIClient, 0&, "AOL Child", vbNullString)
    RICHCNTL = FindWindowEx(lngAOLChild, 0&, "RICHCNTL", vbNullString)
    RICHCNTL = FindWindowEx(lngAOLChild, RICHCNTL, "RICHCNTL", vbNullString)
End Function

'*********************************************************************
' Routine:      SetTopMostWindow
' Description:  Keeps window on top.
' Parameters:   hWnd (Long): Handle to keep on top.
'               bloTopMost (Optional Boolean): True to set on top, False otherwise.
' Notes:        Review
'               http://support.microsoft.com/support/kb/articles/Q150/2/33.ASP
'               for important information.
'*********************************************************************
Public Function SetTopMostWindow _
     (hWnd As Long, _
     Optional bloTopMost As Boolean = True) As Long
    
  On Error GoTo PROC_ERR

  If IsWindow(hWnd) Then
    Select Case bloTopMost
      Case True
        SetTopMostWindow = SetWindowPos(hWnd, HWND_TOPMOST, 0&, 0&, 0&, 0&, FLAGS)
      
      Case False
        SetTopMostWindow = SetWindowPos(hWnd, HWND_NOTOPMOST, 0&, 0&, 0&, 0&, FLAGS)
        SetTopMostWindow = False
    End Select
  Else
    MsgBox "Invalid window.", vbInformation
  End If

  Exit Function
PROC_ERR:
  MsgBox "Error: " & Err.Description & vbCrLf & "Routine: SetTopMostWindow", vbCritical
End Function
